@@ -209,7 +209,7 @@ class AppDetails(Gtk.ScrolledWindow):
         self.app_subtitle.set_visible(True)
         self.description.set_visible(True)
 
-        system_arch = sandbox_sh(['arch'])
+        system_arch = sandbox_sh(['uname', '-m'])
 
         if self.app_list_element.installed_status is InstalledStatus.INSTALLED:
             # Exec arguments
