@@ -9,7 +9,7 @@ from .lib.utils import make_option, url_is_valid
 from .providers.providers_list import appimage_provider
 from .providers.AppImageProvider import AppImageUpdateLogic, AppImageListElement
 from .lib.json_config import read_config_for_app, save_config_for_app
-from .models.UpdateManager import UpdateManagerChecker
+from .models.UpdateManagerChecker import UpdateManagerChecker
 
 class Cli():
     options = [
@@ -48,8 +48,8 @@ class Cli():
 
         if '--help' in argv:
             table = [[f'--{o.long_name}', o.description] for o in Cli.options]
-            text = f'Usage: gearlever [OPTION...]'
-            text += f'\nFor a better user experience, please set `alias gearlever=\'gearlever\'` in your .bashrc file'
+            text = f'Usage: flatpak run {APP_ID} [OPTION...]'
+            text += f'\nFor a better user experience, please set `alias gearlever=\'flatpak run {APP_ID}\'` in your .bashrc file'
             Cli._print_help_if_requested(argv, table, text)
 
         return -1
@@ -154,7 +154,7 @@ class Cli():
         update_url = Cli._get_arg_value(argv, '--url')
         manager_name = Cli._get_arg_value(argv, '--manager')
 
-        if (not update_url) or (not url_is_valid(update_url)):
+        if (not update_url):
             print('Error: "%s" is not a valid URL' % update_url)
             sys.exit(1)
 
@@ -210,7 +210,7 @@ class Cli():
             sys.exit(0)
 
         el.update_logic = AppImageUpdateLogic.KEEP
-        appimage_provider.refresh_title(el)
+        appimage_provider.refresh_data(el)
 
         if '--replace' in argv:
             el.update_logic = AppImageUpdateLogic.REPLACE
