@@ -701,7 +701,7 @@ class AppImageProvider():
 
             if use_unsquashfs:
                 logging.debug('Testing with unsquashfs')
-                appimage_offset = terminal.sandbox_sh(['/usr/share/gearlever/get_appimage_offset', file.get_path()])
+                appimage_offset = terminal.sandbox_sh(['/usr/lib/gearlever/get_appimage_offset', file.get_path()])
 
                 try:
                     terminal.sandbox_sh(['unsquashfs', '-o', appimage_offset, '-l', file.get_path()])
